"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.intersectsWith = void 0;
/**
 * @packageDocumentation
 * @module array
 */
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const intersects_1 = require("../utils/intersects");
/**
 * The `intersectsWith` operator takes a Observable source that is an array of values, and a passed value which is
 * an array or Observable array of values of the same type.
 *
 * An optional predicate method can be passed for more complex types, but if none is passed a simple comparison (`===`)
 * will be used to determine the intersection
 *
 * @param input
 * @param predicate
 */
function intersectsWith(input, predicate) {
    return (source) => input instanceof rxjs_1.Observable
        ? input.pipe(operators_1.switchMap((inputFromSource) => source.pipe(operators_1.map(intersects_1.mapIntersectsWith(inputFromSource, predicate)))))
        : source.pipe(operators_1.map(intersects_1.mapIntersectsWith(input, predicate)));
}
exports.intersectsWith = intersectsWith;
//# sourceMappingURL=intersects-with.js.map