"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapDifference = exports.mapDifferenceWith = void 0;
/**
 * Filter an array to find intersecting items with optional predicate method, otherwise
 * uses simple comparison
 * @param input The input array of values to check against the source
 * @param predicate Optional method for comparison
 *
 * @returns Function that is used with RxJS map method
 * @private
 * @internal
 */
function mapDifferenceWith(input, predicate) {
    return (value) => value.filter((sourceValue) => input.findIndex((checkValue) => (predicate ? predicate(sourceValue, checkValue) : sourceValue === checkValue)) === -1);
}
exports.mapDifferenceWith = mapDifferenceWith;
/**
 *
 * @param checkArray
 * @param mutate
 */
function mapDifference(checkArray, mutate) {
    if (mutate) {
        const checkSet = new Set(checkArray.map(mutate));
        return (value) => [...new Set(value)].filter((x) => !checkSet.has(mutate(x)));
    }
    else {
        const checkSet = new Set(checkArray);
        return (value) => [...new Set(value)].filter((x) => !checkSet.has(x));
    }
}
exports.mapDifference = mapDifference;
//# sourceMappingURL=difference.js.map