"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapIntersection = exports.mapIntersectsWith = void 0;
/**
 * Filter an array to find intersecting items with optional predicate method, otherwise
 * uses simple comparison
 * @param input The input array of values to check against the source
 * @param predicate Optional method for comparison
 *
 * @returns Function that is used with RxJS map method
 * @private
 * @internal
 */
function mapIntersectsWith(input, predicate) {
    return (value) => {
        return value.filter((sourceValue) => input.findIndex((checkValue) => (predicate ? predicate(sourceValue, checkValue) : sourceValue === checkValue)) !== -1);
    };
}
exports.mapIntersectsWith = mapIntersectsWith;
/**
 * Return a method that's used to check that two arrays have intersecting methods,
 * takes an optional method that allows methods to be mutated
 *
 * @param checkArray
 * @param mutate
 * @private
 * @internal
 */
function mapIntersection(checkArray, mutate) {
    if (mutate) {
        const checkSet = new Set(checkArray.map(mutate));
        return (value) => [...new Set(value)].filter((x) => checkSet.has(mutate(x)));
    }
    else {
        const checkSet = new Set(checkArray);
        return (value) => [...new Set(value)].filter((x) => checkSet.has(x));
    }
}
exports.mapIntersection = mapIntersection;
//# sourceMappingURL=intersects.js.map